# Generated by roxygen2: do not edit by hand

export(create_distance_suitability_plot)
export(ecdf_compare_niche)
export(ecdf_nonnormal_niche)
export(ecdf_theoretical_niche)
export(mahal.dist)
export(run_ecdf_mahal_analysis)
import(checkCLI)
importFrom(MASS,mvrnorm)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,sample_frac)
importFrom(dplyr,summarise)
importFrom(dplyr,ungroup)
importFrom(ggplot2,aes)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_pointrange)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,label_both)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_colour_viridis_c)
importFrom(ggplot2,stat_function)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,theme_void)
importFrom(ggplot2,unit)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylim)
importFrom(ggpp,geom_plot_npc)
importFrom(lemon,grid_arrange_shared_legend)
importFrom(purrr,map)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,cov2cor)
importFrom(stats,ecdf)
importFrom(stats,mahalanobis)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,qweibull)
importFrom(stats,rWishart)
importFrom(stats,sd)
importFrom(tidyr,nest)
