# Generated by roxyglobals: do not edit by hand

utils::globalVariables(c(
  # <ecdf_theoretical_niche>
  "",
  # <ecdf_nonnormal_niche>
  # <run_ecdf_mahal_analysis>
  ".data",
  # <ecdf_compare_niche>
  "cor",
  # <ecdf_nonnormal_niche>
  "data",
  NULL
))
