% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{create_distance_suitability_plot}
\alias{create_distance_suitability_plot}
\title{Create distance–suitability plot}
\usage{
create_distance_suitability_plot(analysis_results)
}
\arguments{
\item{analysis_results}{List returned by \code{ecdf_theoretical_niche()}.}
}
\value{
A ggplot object.
}
\description{
Create distance–suitability plot
}
\examples{
# Create ECDF-niche based on personalized options:
res <- ecdf_theoretical_niche(n = 3,
                              n_population = 20000,
                              sample_sizes = seq(50, 1000, 50),
                              seed = 123)

# Plot analysis results
create_distance_suitability_plot(res)

}
